#
#
#
#
# check number of args we got from controller
if [ $# -lt 3 ]
then
	logger -t exacqVision -- Invalid number of args. Got: $#
	exit
fi

## args are passed in from the controller.  "flash install directory" "sd mount point" "sd install dir"
## default is /var/apps/exacqvision
PKGDIR="$1"

# default is /home/httpd/sdcard"
MNT_POINT="$2"

# default install directory is /apps/exacqvision
## which makes the /home/httpd/sdcard/apps/exacqvision
INSTALL_DIR=$MNT_POINT/"$3"

ZIPFILE="edvrserver-arm-vivotek-install.tar.gz"

logger -t exacqVision "Install to " $PKGDIR $INSTALL_DIR $MNT_POINT

# the update script can clobber curl, so we unclobber it here
if [ -e $PKGDIR/curl.new ]; then
  mv $PKGDIR/curl.new $PKGDIR/curl
fi

#
#  see if we need to go through the whole uptar/copy/install process
NEED_UPDATE="0"

# these are the old tests.  Still necessary but not sufficient
# if install directory doesn't exist or core not there 
if [ ! -e $INSTALL_DIR -o ! -e $PKGDIR/core ]
then
	logger -t exacqVision -- "Can't find installation. Creating installation files"
	NEED_UPDATE="1"
fi

#  if we don't have md5 info for the install files, we better be safe
if [ ! -e $PKGDIR/oldmd5.dat ]
then
	logger -t exacqVision -- "Can't find MD5 info. Creating installation files"
	NEED_UPDATE="1"

else
	# we have old md5 info.  generate new value and compare
	NEW_MD5=`md5sum $PKGDIR/install/${ZIPFILE} | cut -d ' ' -f1`

	source $PKGDIR/oldmd5.dat

	if [ "$NEW_MD5" != "$OLD_MD5" ]
	then
		logger -t exacqVision -- "MD5 has changed. Creating installation files" $NEW_MD5 $OLD_MD5
		NEED_UPDATE="1"
	else
		logger -t exacqVision -- "MD5 has not changed." $NEW_MD5 $OLD_MD5
	fi
fi

if [ "$NEED_UPDATE" -ne "0" ]
then
	logger -t exacqVision -- "Start install"
	killall ExacqVision
	sleep 5
	cd $PKGDIR
	mkdir -p $INSTALL_DIR/logs 
	mkdir -p $INSTALL_DIR/audit
	mkdir -p $INSTALL_DIR/blob
	mkdir -p $INSTALL_DIR/edvr
	mkdir -p $INSTALL_DIR/posdata
	mkdir -p $INSTALL_DIR/edvr/0
	mkdir -p $INSTALL_DIR/data
	rm -rf $INSTALL_DIR/plugins
	rm core

	tar zxf install/${ZIPFILE}
	tar -xf edvrserver-arm-vivotek-install.tar
	logger -t exacqVision -- "Done expanding tarred installation files"
	for fil in `ls exacq`
	do
	    ext=`basename $fil | cut -s -d'.' -f2`
	    if [ "$ext" = "xml" ]
	    then
		if [ ! -e ./$fil ]
		then
		    mv exacq/$fil .
		fi
	    else
		mv exacq/$fil .
	    fi
	done
	rm edvrserver-arm-vivotek-install.tar
	chmod +x $PKGDIR/core

	cd $PKGDIR
	cd lib
	logger -t exacqVision -- "creating library links"
	pwd | logger -t exacqVision 
	chmod +x ../install/create_links.sh
	source ../install/create_links.sh

	cd ..
	touch $INSTALL_DIR/pospi.db
	touch $INSTALL_DIR/pospi.db-shm
	touch $INSTALL_DIR/pospi.db-wal

	logger -t exacqVision -- "All runtime files created"
	echo export OLD_MD5=`md5sum $PKGDIR/install/${ZIPFILE} | cut -d ' ' -f1` >oldmd5.dat
	./ExacqVision -i $1 -m $2 -s $3 &

else
	logger -t exacqVision - "Runtime files are already installed"
fi
